@@ -68,7 +68,9 @@ update_tab_visibility (TerminalNotebook *notebook,
     show_tabs = (gtk_notebook_get_n_pages (gtk_notebook) + change) > 1;
     break;
   case GTK_POLICY_NEVER:
+#if GTK_CHECK_VERSION (3, 16, 0)
   case GTK_POLICY_EXTERNAL:
+#endif
   default:
     show_tabs = FALSE;
     break;
